Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mumble-voip/mumble.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to '.ci/azure-pipelines/build_linux.bash')
-rwxr-xr-x.ci/azure-pipelines/build_linux.bash6
1 files changed, 3 insertions, 3 deletions
diff --git a/.ci/azure-pipelines/build_linux.bash b/.ci/azure-pipelines/build_linux.bash
index a1f7e9fe0..f5cca72fa 100755
--- a/.ci/azure-pipelines/build_linux.bash
+++ b/.ci/azure-pipelines/build_linux.bash
@@ -16,12 +16,12 @@
#
# Defined on Azure Pipelines:
#
# BUILD_NUMBER_TOKEN - Access token for the build number page on our server.
#
-if [[ -n "$BUILD_NUMBER_TOKEN" ]]; then
+if [[ -n "$MUMBLE_BUILD_NUMBER_TOKEN" ]]; then
VERSION=$(python "scripts/mumble-version.py" --project)
- BUILD_NUMBER=$(curl "https://mumble.info/get-build-number?version=$VERSION_$AGENT_JOBNAME&token=$BUILD_NUMBER_TOKEN")
+ BUILD_NUMBER=$(curl "https://mumble.info/get-build-number?version=$VERSION_$AGENT_JOBNAME&token=$MUMBLE_BUILD_NUMBER_TOKEN")
else
BUILD_NUMBER=0
fi
@@ -16,12 +16,12 @@
# Defined on Azure Pipelines:
#
-# BUILD_NUMBER_TOKEN - Access token for the build number page on our server.
+# MUMBLE_BUILD_NUMBER_TOKEN - Access token for the build number page on our server.
#